"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.spark.v1.job_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    job_id: builtins.str
    """ID of the Spark job to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id"]) -> None: ...

global___GetJobRequest = GetJobRequest

@typing.final
class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list Spark jobs of."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListJobs requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListJobs
    request to get the next page of results.
    """
    filter: builtins.str
    """String that describes a display filter."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

@typing.final
class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListJobs requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListClusters request. Subsequent ListClusters
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.spark.v1.job_pb2.Job]:
        """Requested list of Spark jobs."""

    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[yandex.cloud.spark.v1.job_pb2.Job] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["jobs", b"jobs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

@typing.final
class CreateJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SPARK_JOB_FIELD_NUMBER: builtins.int
    PYSPARK_JOB_FIELD_NUMBER: builtins.int
    SPARK_CONNECT_JOB_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to create Spark job in."""
    name: builtins.str
    """Optional. Name of the job."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources."""
    @property
    def spark_job(self) -> yandex.cloud.spark.v1.job_pb2.SparkJob: ...
    @property
    def pyspark_job(self) -> yandex.cloud.spark.v1.job_pb2.PysparkJob: ...
    @property
    def spark_connect_job(self) -> yandex.cloud.spark.v1.job_pb2.SparkConnectJob: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        spark_job: yandex.cloud.spark.v1.job_pb2.SparkJob | None = ...,
        pyspark_job: yandex.cloud.spark.v1.job_pb2.PysparkJob | None = ...,
        spark_connect_job: yandex.cloud.spark.v1.job_pb2.SparkConnectJob | None = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["job_spec", b"job_spec", "pyspark_job", b"pyspark_job", "spark_connect_job", b"spark_connect_job", "spark_job", b"spark_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_spec", b"job_spec", "name", b"name", "pyspark_job", b"pyspark_job", "service_account_id", b"service_account_id", "spark_connect_job", b"spark_connect_job", "spark_job", b"spark_job"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["job_spec", b"job_spec"]) -> typing.Literal["spark_job", "pyspark_job", "spark_connect_job"] | None: ...

global___CreateJobRequest = CreateJobRequest

@typing.final
class CreateJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    job_id: builtins.str
    """ID of the Spark job."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id"]) -> None: ...

global___CreateJobMetadata = CreateJobMetadata

@typing.final
class CancelJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    job_id: builtins.str
    """ID of the Spark job to cancel."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id"]) -> None: ...

global___CancelJobRequest = CancelJobRequest

@typing.final
class ListJobLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Spark cluster."""
    job_id: builtins.str
    """ID of the Spark job to return."""
    page_size: builtins.int
    """The maximum length of job output per papge that should be returned.
    If the number of available output is larger tha `page_size`, the service returns
    a `next_page_token` that can be used to get the next page of job output in subsequent ListLog requests.
    Acceptable values are 0 to 1048576. Default value: 1048576.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListLog
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListJobLogRequest = ListJobLogRequest

@typing.final
class ListJobLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    content: builtins.str
    """Requested part of Spark Job log."""
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListLog requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListLog request. Subsequent ListLog
    requests will have their own `next_page_token` to continue paging through the results.
    """
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "next_page_token", b"next_page_token"]) -> None: ...

global___ListJobLogResponse = ListJobLogResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.containerregistry.v1.ip_permission_pb2
import yandex.cloud.containerregistry.v1.registry_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry resource to return.

    To get the registry ID use a [RegistryService.List] request.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___GetRegistryRequest = GetRegistryRequest

@typing.final
class ListRegistriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list registries in.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRegistriesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRegistriesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Registry.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListRegistriesRequest = ListRegistriesRequest

@typing.final
class ListRegistriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRegistriesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListRegistriesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.registry_pb2.Registry]:
        """List of Registry resources."""

    def __init__(
        self,
        *,
        registries: collections.abc.Iterable[yandex.cloud.containerregistry.v1.registry_pb2.Registry] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "registries", b"registries"]) -> None: ...

global___ListRegistriesResponse = ListRegistriesResponse

@typing.final
class CreateRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SECURE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a registry in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the registry.

    There may be only one registry per folder.
    """
    secure: builtins.bool
    """If true, registry will be created with pre-setup scanning policy (on push and on schedule every 7 days)"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        secure: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "labels", b"labels", "name", b"name", "secure", b"secure"]) -> None: ...

global___CreateRegistryRequest = CreateRegistryRequest

@typing.final
class CreateRegistryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that is being created."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___CreateRegistryMetadata = CreateRegistryMetadata

@typing.final
class UpdateRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry resource to update.

    To get the registry ID use a [RegistryService.List] request.
    """
    name: builtins.str
    """Name of the registry.

    There may be only one registry per folder.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Registry resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["labels", b"labels", "name", b"name", "registry_id", b"registry_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateRegistryRequest = UpdateRegistryRequest

@typing.final
class UpdateRegistryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry resource that is being updated."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___UpdateRegistryMetadata = UpdateRegistryMetadata

@typing.final
class DeleteRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to delete."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___DeleteRegistryRequest = DeleteRegistryRequest

@typing.final
class DeleteRegistryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that is being deleted."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___DeleteRegistryMetadata = DeleteRegistryMetadata

@typing.final
class SetIpPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    IP_PERMISSION_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry for which ip permissions are being set."""
    @property
    def ip_permission(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.ip_permission_pb2.IpPermission]:
        """IP permission to be set."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        ip_permission: collections.abc.Iterable[yandex.cloud.containerregistry.v1.ip_permission_pb2.IpPermission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_permission", b"ip_permission", "registry_id", b"registry_id"]) -> None: ...

global___SetIpPermissionRequest = SetIpPermissionRequest

@typing.final
class UpdateIpPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    IP_PERMISSION_DELTAS_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry for which ip permissions are being updated."""
    @property
    def ip_permission_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.ip_permission_pb2.IpPermissionDelta]:
        """Updates to IP permissions."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        ip_permission_deltas: collections.abc.Iterable[yandex.cloud.containerregistry.v1.ip_permission_pb2.IpPermissionDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_permission_deltas", b"ip_permission_deltas", "registry_id", b"registry_id"]) -> None: ...

global___UpdateIpPermissionRequest = UpdateIpPermissionRequest

@typing.final
class ListIpPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry to return ip permission list."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___ListIpPermissionRequest = ListIpPermissionRequest

@typing.final
class ListIpPermissionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMISSIONS_FIELD_NUMBER: builtins.int
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.ip_permission_pb2.IpPermission]:
        """List of ip permissions for registry"""

    def __init__(
        self,
        *,
        permissions: collections.abc.Iterable[yandex.cloud.containerregistry.v1.ip_permission_pb2.IpPermission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["permissions", b"permissions"]) -> None: ...

global___ListIpPermissionsResponse = ListIpPermissionsResponse

@typing.final
class SetIpPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that ip permission is being set."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___SetIpPermissionMetadata = SetIpPermissionMetadata

@typing.final
class UpdateIpPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that ip permission is being updated."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___UpdateIpPermissionMetadata = UpdateIpPermissionMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Address(google.protobuf.message.Message):
    """An Address resource. For more information, see [Address](/docs/vpc/concepts/address)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Address._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Address._Type.ValueType  # 0
        INTERNAL: Address._Type.ValueType  # 1
        """Internal IP address."""
        EXTERNAL: Address._Type.ValueType  # 2
        """Public IP address."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Address.Type.ValueType  # 0
    INTERNAL: Address.Type.ValueType  # 1
    """Internal IP address."""
    EXTERNAL: Address.Type.ValueType  # 2
    """Public IP address."""

    class _IpVersion:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _IpVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Address._IpVersion.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IP_VERSION_UNSPECIFIED: Address._IpVersion.ValueType  # 0
        IPV4: Address._IpVersion.ValueType  # 1
        """IPv4 address."""
        IPV6: Address._IpVersion.ValueType  # 2
        """IPv6 address."""

    class IpVersion(_IpVersion, metaclass=_IpVersionEnumTypeWrapper): ...
    IP_VERSION_UNSPECIFIED: Address.IpVersion.ValueType  # 0
    IPV4: Address.IpVersion.ValueType  # 1
    """IPv4 address."""
    IPV6: Address.IpVersion.ValueType  # 2
    """IPv6 address."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    RESERVED_FIELD_NUMBER: builtins.int
    USED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DNS_RECORDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the address. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the address belongs to."""
    name: builtins.str
    """Name of the address.
    The name is unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Description of the address. 0-256 characters long."""
    reserved: builtins.bool
    """Specifies if address is reserved or not."""
    used: builtins.bool
    """Specifies if address is used or not."""
    type: global___Address.Type.ValueType
    """Type of the IP address."""
    ip_version: global___Address.IpVersion.ValueType
    """Version of the IP address."""
    deletion_protection: builtins.bool
    """Specifies if address protected from deletion."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Address labels as `key:value` pairs. 
        No more than 64 per resource. 
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`. 
        The string length in characters for each key must be 1-63. 
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    @property
    def external_ipv4_address(self) -> global___ExternalIpv4Address: ...
    @property
    def dns_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecord]:
        """Optional DNS record specifications"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        external_ipv4_address: global___ExternalIpv4Address | None = ...,
        reserved: builtins.bool = ...,
        used: builtins.bool = ...,
        type: global___Address.Type.ValueType = ...,
        ip_version: global___Address.IpVersion.ValueType = ...,
        deletion_protection: builtins.bool = ...,
        dns_records: collections.abc.Iterable[global___DnsRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "created_at", b"created_at", "external_ipv4_address", b"external_ipv4_address"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "dns_records", b"dns_records", "external_ipv4_address", b"external_ipv4_address", "folder_id", b"folder_id", "id", b"id", "ip_version", b"ip_version", "labels", b"labels", "name", b"name", "reserved", b"reserved", "type", b"type", "used", b"used"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["external_ipv4_address"] | None: ...

global___Address = Address

@typing.final
class ExternalIpv4Address(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    REQUIREMENTS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """Value of address."""
    zone_id: builtins.str
    """Availability zone from which the address will be allocated."""
    @property
    def requirements(self) -> global___AddressRequirements:
        """Parameters of the allocated address, for example DDoS Protection."""

    def __init__(
        self,
        *,
        address: builtins.str = ...,
        zone_id: builtins.str = ...,
        requirements: global___AddressRequirements | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["requirements", b"requirements"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "requirements", b"requirements", "zone_id", b"zone_id"]) -> None: ...

global___ExternalIpv4Address = ExternalIpv4Address

@typing.final
class AddressRequirements(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DDOS_PROTECTION_PROVIDER_FIELD_NUMBER: builtins.int
    OUTGOING_SMTP_CAPABILITY_FIELD_NUMBER: builtins.int
    ddos_protection_provider: builtins.str
    """DDoS protection provider ID."""
    outgoing_smtp_capability: builtins.str
    """Capability to send SMTP traffic."""
    def __init__(
        self,
        *,
        ddos_protection_provider: builtins.str = ...,
        outgoing_smtp_capability: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ddos_protection_provider", b"ddos_protection_provider", "outgoing_smtp_capability", b"outgoing_smtp_capability"]) -> None: ...

global___AddressRequirements = AddressRequirements

@typing.final
class DnsRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    PTR_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    """DNS record name (absolute or relative to the DNS zone in use)."""
    dns_zone_id: builtins.str
    """ID of the public DNS zone."""
    ttl: builtins.int
    """TTL of record."""
    ptr: builtins.bool
    """If the PTR record is required, this parameter must be set to "true"."""
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        dns_zone_id: builtins.str = ...,
        ttl: builtins.int = ...,
        ptr: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "fqdn", b"fqdn", "ptr", b"ptr", "ttl", b"ttl"]) -> None: ...

global___DnsRecord = DnsRecord



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _NormalizationStrategy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NormalizationStrategyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NormalizationStrategy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NORMALIZATION_STRATEGY_UNSPECIFIED: _NormalizationStrategy.ValueType  # 0
    MIN_MAX: _NormalizationStrategy.ValueType  # 1
    """https://en.wikipedia.org/wiki/Feature_scaling#Rescaling_(min-max_normalization)"""
    L2: _NormalizationStrategy.ValueType  # 2
    """https://en.wikipedia.org/wiki/Cosine_similarity#L2-normalized_Euclidean_distance"""

class NormalizationStrategy(_NormalizationStrategy, metaclass=_NormalizationStrategyEnumTypeWrapper):
    """Normalization strategy for relevance scores from different indices"""

NORMALIZATION_STRATEGY_UNSPECIFIED: NormalizationStrategy.ValueType  # 0
MIN_MAX: NormalizationStrategy.ValueType  # 1
"""https://en.wikipedia.org/wiki/Feature_scaling#Rescaling_(min-max_normalization)"""
L2: NormalizationStrategy.ValueType  # 2
"""https://en.wikipedia.org/wiki/Cosine_similarity#L2-normalized_Euclidean_distance"""
global___NormalizationStrategy = NormalizationStrategy

@typing.final
class StaticChunkingStrategy(google.protobuf.message.Message):
    """Defines a chunking strategy where chunks are created with a fixed maximum chunk size and an overlap between consecutive chunks."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CHUNK_SIZE_TOKENS_FIELD_NUMBER: builtins.int
    CHUNK_OVERLAP_TOKENS_FIELD_NUMBER: builtins.int
    max_chunk_size_tokens: builtins.int
    """The maximum number of tokens allowed in a single chunk.
    Constraints: must be within the range [100, 2048].
    Default value: 800
    """
    chunk_overlap_tokens: builtins.int
    """The number of tokens that should overlap between consecutive chunks.
    This allows for some context from the previous chunk to be included in the next chunk.
    Constraints: must be less than or equal to half of `max_chunk_size_tokens`.
    Default value: 400
    """
    def __init__(
        self,
        *,
        max_chunk_size_tokens: builtins.int = ...,
        chunk_overlap_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chunk_overlap_tokens", b"chunk_overlap_tokens", "max_chunk_size_tokens", b"max_chunk_size_tokens"]) -> None: ...

global___StaticChunkingStrategy = StaticChunkingStrategy

@typing.final
class ChunkingStrategy(google.protobuf.message.Message):
    """Defines a general strategy for chunking text into smaller segments.
    Currently, only StaticChunkingStrategy is supported.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATIC_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def static_strategy(self) -> global___StaticChunkingStrategy: ...
    def __init__(
        self,
        *,
        static_strategy: global___StaticChunkingStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Strategy", b"Strategy", "static_strategy", b"static_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Strategy", b"Strategy", "static_strategy", b"static_strategy"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Strategy", b"Strategy"]) -> typing.Literal["static_strategy"] | None: ...

global___ChunkingStrategy = ChunkingStrategy

@typing.final
class MeanCombinationStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MeanEvaluationTechnique:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MeanEvaluationTechniqueEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MeanCombinationStrategy._MeanEvaluationTechnique.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MEAN_EVALUATION_TECHNIQUE_UNSPECIFIED: MeanCombinationStrategy._MeanEvaluationTechnique.ValueType  # 0
        ARITHMETIC: MeanCombinationStrategy._MeanEvaluationTechnique.ValueType  # 1
        """https://en.wikipedia.org/wiki/Arithmetic_mean"""
        GEOMETRIC: MeanCombinationStrategy._MeanEvaluationTechnique.ValueType  # 2
        """https://en.wikipedia.org/wiki/Geometric_mean"""
        HARMONIC: MeanCombinationStrategy._MeanEvaluationTechnique.ValueType  # 3
        """https://en.wikipedia.org/wiki/Harmonic_mean"""

    class MeanEvaluationTechnique(_MeanEvaluationTechnique, metaclass=_MeanEvaluationTechniqueEnumTypeWrapper): ...
    MEAN_EVALUATION_TECHNIQUE_UNSPECIFIED: MeanCombinationStrategy.MeanEvaluationTechnique.ValueType  # 0
    ARITHMETIC: MeanCombinationStrategy.MeanEvaluationTechnique.ValueType  # 1
    """https://en.wikipedia.org/wiki/Arithmetic_mean"""
    GEOMETRIC: MeanCombinationStrategy.MeanEvaluationTechnique.ValueType  # 2
    """https://en.wikipedia.org/wiki/Geometric_mean"""
    HARMONIC: MeanCombinationStrategy.MeanEvaluationTechnique.ValueType  # 3
    """https://en.wikipedia.org/wiki/Harmonic_mean"""

    MEAN_EVALUATION_TECHNIQUE_FIELD_NUMBER: builtins.int
    WEIGHTS_FIELD_NUMBER: builtins.int
    mean_evaluation_technique: global___MeanCombinationStrategy.MeanEvaluationTechnique.ValueType
    """Technique for averaging relevance scores from different indices. Default is ARITHMETIC"""
    @property
    def weights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Weights used for evaluating the weighted mean of relevance scores. The sum of the values must equal 1.0
        If not provided, all scores are given equal weight
        """

    def __init__(
        self,
        *,
        mean_evaluation_technique: global___MeanCombinationStrategy.MeanEvaluationTechnique.ValueType = ...,
        weights: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mean_evaluation_technique", b"mean_evaluation_technique", "weights", b"weights"]) -> None: ...

global___MeanCombinationStrategy = MeanCombinationStrategy

@typing.final
class ReciprocalRankFusionCombinationStrategy(google.protobuf.message.Message):
    """https://plg.uwaterloo.ca/~gvcormac/cormacksigir09-rrf.pdf"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    K_FIELD_NUMBER: builtins.int
    @property
    def k(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The parameter k for RRFscore. Default is 60"""

    def __init__(
        self,
        *,
        k: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["k", b"k"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["k", b"k"]) -> None: ...

global___ReciprocalRankFusionCombinationStrategy = ReciprocalRankFusionCombinationStrategy

@typing.final
class CombinationStrategy(google.protobuf.message.Message):
    """Combination strategy for merging rankings from different indices"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEAN_COMBINATION_FIELD_NUMBER: builtins.int
    RRF_COMBINATION_FIELD_NUMBER: builtins.int
    @property
    def mean_combination(self) -> global___MeanCombinationStrategy: ...
    @property
    def rrf_combination(self) -> global___ReciprocalRankFusionCombinationStrategy: ...
    def __init__(
        self,
        *,
        mean_combination: global___MeanCombinationStrategy | None = ...,
        rrf_combination: global___ReciprocalRankFusionCombinationStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Strategy", b"Strategy", "mean_combination", b"mean_combination", "rrf_combination", b"rrf_combination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Strategy", b"Strategy", "mean_combination", b"mean_combination", "rrf_combination", b"rrf_combination"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Strategy", b"Strategy"]) -> typing.Literal["mean_combination", "rrf_combination"] | None: ...

global___CombinationStrategy = CombinationStrategy

@typing.final
class NgramTokenizer(google.protobuf.message.Message):
    """Configuration for the NgramTokenizer, which splits text into overlapping character sequences (n-grams) of specified lengths.

    Example:
    Input text: `hello`
    min_gram = 2, max_gram = 3

    Generated tokens:
    * For n = 2 (2-character n-grams): `he`, `el`, `ll`, `lo`
    * For n = 3 (3-character n-grams): `hel`, `ell`, `llo`

    Final tokens: `[he, el, ll, lo, hel, ell, llo]`
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_GRAM_FIELD_NUMBER: builtins.int
    MAX_GRAM_FIELD_NUMBER: builtins.int
    @property
    def min_gram(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Minimum length of characters in a gram. Defaults to 3"""

    @property
    def max_gram(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum length of characters in a gram. Defaults to 4"""

    def __init__(
        self,
        *,
        min_gram: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_gram: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_gram", b"max_gram", "min_gram", b"min_gram"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_gram", b"max_gram", "min_gram", b"min_gram"]) -> None: ...

global___NgramTokenizer = NgramTokenizer

@typing.final
class StandardTokenizer(google.protobuf.message.Message):
    """A standard tokenizer that splits text on word boundaries and removes punctuation.
    It follows the Unicode Text Segmentation rules as specified in Unicode Standard Annex #29.

    Example:
    Input text: `Hello, world! How are you?`
    Output tokens: `[Hello, world, How, are, you]`
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StandardTokenizer = StandardTokenizer

@typing.final
class StandardAnalyzer(google.protobuf.message.Message):
    """A standard analyzer that uses StandardTokenizer."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StandardAnalyzer = StandardAnalyzer

@typing.final
class YandexLemmerAnalyzer(google.protobuf.message.Message):
    """A specialized analyzer that uses Yandex's lemmatization technology to reduce words to their base forms.
    Particularly effective for Russian and other Slavic languages, handling their complex morphology.
    For more information, see:
    https://yandex.cloud/en/docs/tutorials/dataplatform/opensearch-yandex-lemmer
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___YandexLemmerAnalyzer = YandexLemmerAnalyzer



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.gitlab.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Instance(google.protobuf.message.Message):
    """Instance represents a GitLab instance with its configuration and state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Instance._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Instance._Status.ValueType  # 0
        """Default state."""
        CREATING: Instance._Status.ValueType  # 1
        """Instance is being created."""
        RUNNING: Instance._Status.ValueType  # 2
        """Instance is running normally."""
        UPDATING: Instance._Status.ValueType  # 3
        """Instance is being updated."""
        ERROR: Instance._Status.ValueType  # 4
        """Instance is in error state."""
        DELETING: Instance._Status.ValueType  # 5
        """Instance is being deleted."""
        BACKUP_CREATING: Instance._Status.ValueType  # 6
        """Backup is being created."""
        BACKUP_RESTORING: Instance._Status.ValueType  # 7
        """Backup is being restored."""
        STARTING: Instance._Status.ValueType  # 8
        """Instance is starting."""
        STOPPING: Instance._Status.ValueType  # 9
        """Instance is stopping."""
        STOPPED: Instance._Status.ValueType  # 10
        """Instance is stopped."""
        BACKGROUND_MIGRATIONS: Instance._Status.ValueType  # 11
        """Background migrations in progress."""
        OBJECT_STORAGE_MIGRATIONS: Instance._Status.ValueType  # 12
        """Object storage migrations in progress."""
        SNAPSHOT_RESTORING: Instance._Status.ValueType  # 13
        """Snapshot is being restored."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Instance.Status.ValueType  # 0
    """Default state."""
    CREATING: Instance.Status.ValueType  # 1
    """Instance is being created."""
    RUNNING: Instance.Status.ValueType  # 2
    """Instance is running normally."""
    UPDATING: Instance.Status.ValueType  # 3
    """Instance is being updated."""
    ERROR: Instance.Status.ValueType  # 4
    """Instance is in error state."""
    DELETING: Instance.Status.ValueType  # 5
    """Instance is being deleted."""
    BACKUP_CREATING: Instance.Status.ValueType  # 6
    """Backup is being created."""
    BACKUP_RESTORING: Instance.Status.ValueType  # 7
    """Backup is being restored."""
    STARTING: Instance.Status.ValueType  # 8
    """Instance is starting."""
    STOPPING: Instance.Status.ValueType  # 9
    """Instance is stopping."""
    STOPPED: Instance.Status.ValueType  # 10
    """Instance is stopped."""
    BACKGROUND_MIGRATIONS: Instance.Status.ValueType  # 11
    """Background migrations in progress."""
    OBJECT_STORAGE_MIGRATIONS: Instance.Status.ValueType  # 12
    """Object storage migrations in progress."""
    SNAPSHOT_RESTORING: Instance.Status.ValueType  # 13
    """Snapshot is being restored."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ADMIN_LOGIN_FIELD_NUMBER: builtins.int
    ADMIN_EMAIL_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    MAINTENANCE_DELETE_UNTAGGED_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    APPROVAL_RULES_ID_FIELD_NUMBER: builtins.int
    GITLAB_VERSION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique instance ID."""
    folder_id: builtins.str
    """Folder ID where instance resides."""
    name: builtins.str
    """Human-readable name."""
    description: builtins.str
    """Instance description."""
    resource_preset_id: builtins.str
    """Resource preset ID."""
    disk_size: builtins.int
    """Disk size in bytes."""
    status: global___Instance.Status.ValueType
    """Current instance status."""
    admin_login: builtins.str
    """Admin username."""
    admin_email: builtins.str
    """Admin email."""
    domain: builtins.str
    """Instance domain."""
    subnet_id: builtins.str
    """Subnet ID."""
    backup_retain_period_days: builtins.int
    """How long to keep backups (days)."""
    maintenance_delete_untagged: builtins.bool
    """Delete untagged resources during maintenance."""
    deletion_protection: builtins.bool
    """Protect from accidental deletion."""
    approval_rules_id: builtins.str
    """Approval rules ID."""
    gitlab_version: builtins.str
    """GitLab version of the instance."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last update timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as key-value pairs."""

    @property
    def planned_operation(self) -> yandex.cloud.gitlab.v1.maintenance_pb2.MaintenanceOperation:
        """Planned maintenance operation."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        status: global___Instance.Status.ValueType = ...,
        admin_login: builtins.str = ...,
        admin_email: builtins.str = ...,
        domain: builtins.str = ...,
        subnet_id: builtins.str = ...,
        planned_operation: yandex.cloud.gitlab.v1.maintenance_pb2.MaintenanceOperation | None = ...,
        backup_retain_period_days: builtins.int = ...,
        maintenance_delete_untagged: builtins.bool = ...,
        deletion_protection: builtins.bool = ...,
        approval_rules_id: builtins.str = ...,
        gitlab_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "planned_operation", b"planned_operation", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admin_email", b"admin_email", "admin_login", b"admin_login", "approval_rules_id", b"approval_rules_id", "backup_retain_period_days", b"backup_retain_period_days", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "disk_size", b"disk_size", "domain", b"domain", "folder_id", b"folder_id", "gitlab_version", b"gitlab_version", "id", b"id", "labels", b"labels", "maintenance_delete_untagged", b"maintenance_delete_untagged", "name", b"name", "planned_operation", b"planned_operation", "resource_preset_id", b"resource_preset_id", "status", b"status", "subnet_id", b"subnet_id", "updated_at", b"updated_at"]) -> None: ...

global___Instance = Instance



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/manager/v1/job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/manager/v1/job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/dataproc/manager/v1/job.proto\x12 yandex.cloud.dataproc.manager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x80\x06\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\x12<\n\x06status\x18\x07 \x01(\x0e\x32,.yandex.cloud.dataproc.manager.v1.Job.Status\x12G\n\rmapreduce_job\x18\x08 \x01(\x0b\x32..yandex.cloud.dataproc.manager.v1.MapreduceJobH\x00\x12?\n\tspark_job\x18\t \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.SparkJobH\x00\x12\x43\n\x0bpyspark_job\x18\n \x01(\x0b\x32,.yandex.cloud.dataproc.manager.v1.PysparkJobH\x00\x12=\n\x08hive_job\x18\x0b \x01(\x0b\x32).yandex.cloud.dataproc.manager.v1.HiveJobH\x00\x12K\n\x10\x61pplication_info\x18\r \x01(\x0b\x32\x31.yandex.cloud.dataproc.manager.v1.ApplicationInfo\"\x80\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x08\n\x04\x44ONE\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\x0e\n\nCANCELLING\x10\x07\x42\n\n\x08job_spec\"9\n\x12\x41pplicationAttempt\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61m_container_id\x18\x02 \x01(\t\"q\n\x0f\x41pplicationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12R\n\x14\x61pplication_attempts\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.dataproc.manager.v1.ApplicationAttempt\"\xa0\x02\n\x0cMapreduceJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12R\n\nproperties\x18\x05 \x03(\x0b\x32>.yandex.cloud.dataproc.manager.v1.MapreduceJob.PropertiesEntry\x12\x1b\n\x11main_jar_file_uri\x18\x06 \x01(\tH\x00\x12\x14\n\nmain_class\x18\x07 \x01(\tH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06\x64river\"\xcc\x02\n\x08SparkJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12N\n\nproperties\x18\x05 \x03(\x0b\x32:.yandex.cloud.dataproc.manager.v1.SparkJob.PropertiesEntry\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12\x12\n\nmain_class\x18\x07 \x01(\t\x12\x10\n\x08packages\x18\x08 \x03(\t\x12\x14\n\x0crepositories\x18\t \x03(\t\x12\x18\n\x10\x65xclude_packages\x18\n \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x02\n\nPysparkJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12P\n\nproperties\x18\x05 \x03(\x0b\x32<.yandex.cloud.dataproc.manager.v1.PysparkJob.PropertiesEntry\x12\x1c\n\x14main_python_file_uri\x18\x06 \x01(\t\x12\x18\n\x10python_file_uris\x18\x07 \x03(\t\x12\x10\n\x08packages\x18\x08 \x03(\t\x12\x14\n\x0crepositories\x18\t \x03(\t\x12\x18\n\x10\x65xclude_packages\x18\n \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\tQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xbc\x03\n\x07HiveJob\x12M\n\nproperties\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.dataproc.manager.v1.HiveJob.PropertiesEntry\x12\x1b\n\x13\x63ontinue_on_failure\x18\x02 \x01(\x08\x12X\n\x10script_variables\x18\x03 \x03(\x0b\x32>.yandex.cloud.dataproc.manager.v1.HiveJob.ScriptVariablesEntry\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x18\n\x0equery_file_uri\x18\x05 \x01(\tH\x00\x12\x41\n\nquery_list\x18\x06 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.QueryListH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nquery_type\"\xb7\x03\n\nSupportJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06status\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.dataproc.manager.v1.SupportJob.Status\x12\x0b\n\x03\x63md\x18\x07 \x01(\t\x12\x0f\n\x07timeout\x18\x08 \x01(\x03\x12\x12\n\ncreated_by\x18\t \x01(\t\"\x80\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x08\n\x04\x44ONE\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\x0e\n\nCANCELLING\x10\x07\x42}\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_managerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.manager.v1.job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_manager'
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_SPARKJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_SPARKJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVEJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_HIVEJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._loaded_options = None
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_JOB']._serialized_start=114
  _globals['_JOB']._serialized_end=882
  _globals['_JOB_STATUS']._serialized_start=742
  _globals['_JOB_STATUS']._serialized_end=870
  _globals['_APPLICATIONATTEMPT']._serialized_start=884
  _globals['_APPLICATIONATTEMPT']._serialized_end=941
  _globals['_APPLICATIONINFO']._serialized_start=943
  _globals['_APPLICATIONINFO']._serialized_end=1056
  _globals['_MAPREDUCEJOB']._serialized_start=1059
  _globals['_MAPREDUCEJOB']._serialized_end=1347
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._serialized_start=1288
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._serialized_end=1337
  _globals['_SPARKJOB']._serialized_start=1350
  _globals['_SPARKJOB']._serialized_end=1682
  _globals['_SPARKJOB_PROPERTIESENTRY']._serialized_start=1288
  _globals['_SPARKJOB_PROPERTIESENTRY']._serialized_end=1337
  _globals['_PYSPARKJOB']._serialized_start=1685
  _globals['_PYSPARKJOB']._serialized_end=2030
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._serialized_start=1288
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._serialized_end=1337
  _globals['_QUERYLIST']._serialized_start=2032
  _globals['_QUERYLIST']._serialized_end=2060
  _globals['_HIVEJOB']._serialized_start=2063
  _globals['_HIVEJOB']._serialized_end=2507
  _globals['_HIVEJOB_PROPERTIESENTRY']._serialized_start=1288
  _globals['_HIVEJOB_PROPERTIESENTRY']._serialized_end=1337
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._serialized_start=2439
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._serialized_end=2493
  _globals['_SUPPORTJOB']._serialized_start=2510
  _globals['_SUPPORTJOB']._serialized_end=2949
  _globals['_SUPPORTJOB_STATUS']._serialized_start=742
  _globals['_SUPPORTJOB_STATUS']._serialized_end=870
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.vrf_pb2
import yandex.cloud.baremetal.v1alpha.vrf_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class VrfServiceStub:
    """A set of methods for managing VRF resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.GetVrfRequest,
        yandex.cloud.baremetal.v1alpha.vrf_pb2.Vrf,
    ]
    """Returns the specific VRF resource.

    To get the list of available VRFs, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfRequest,
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfResponse,
    ]
    """Retrieves the list of VRF resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.CreateVrfRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a VRF in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.UpdateVrfRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified VRF resource."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.DeleteVrfRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified VRF resource.

    Deleting a VRF removes its data permanently and is irreversible.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsRequest,
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsResponse,
    ]
    """Lists operations for the specified VRF."""

class VrfServiceAsyncStub:
    """A set of methods for managing VRF resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.GetVrfRequest,
        yandex.cloud.baremetal.v1alpha.vrf_pb2.Vrf,
    ]
    """Returns the specific VRF resource.

    To get the list of available VRFs, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfRequest,
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfResponse,
    ]
    """Retrieves the list of VRF resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.CreateVrfRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a VRF in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.UpdateVrfRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified VRF resource."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.DeleteVrfRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified VRF resource.

    Deleting a VRF removes its data permanently and is irreversible.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsRequest,
        yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsResponse,
    ]
    """Lists operations for the specified VRF."""

class VrfServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing VRF resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.baremetal.v1alpha.vrf_service_pb2.GetVrfRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.vrf_pb2.Vrf, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.vrf_pb2.Vrf]]:
        """Returns the specific VRF resource.

        To get the list of available VRFs, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfResponse]]:
        """Retrieves the list of VRF resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.baremetal.v1alpha.vrf_service_pb2.CreateVrfRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a VRF in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.baremetal.v1alpha.vrf_service_pb2.UpdateVrfRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified VRF resource."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.baremetal.v1alpha.vrf_service_pb2.DeleteVrfRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified VRF resource.

        Deleting a VRF removes its data permanently and is irreversible.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.vrf_service_pb2.ListVrfOperationsResponse]]:
        """Lists operations for the specified VRF."""

def add_VrfServiceServicer_to_server(servicer: VrfServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/extension_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/extension_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_extension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/clickhouse/v1/extension_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/mdb/clickhouse/v1/extension.proto\"X\n\x13GetExtensionRequest\x12$\n\x0e\x65xtension_name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x1b\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"r\n\x15ListExtensionsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1b\n\tfolder_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"p\n\x16ListExtensionsResponse\x12=\n\nextensions\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Extension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd9\x02\n\x10\x45xtensionService\x12\xa1\x01\n\x03Get\x12\x33.yandex.cloud.mdb.clickhouse.v1.GetExtensionRequest\x1a).yandex.cloud.mdb.clickhouse.v1.Extension\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-clickhouse/v1/extensions/{extension_name}\x12\xa0\x01\n\x04List\x12\x35.yandex.cloud.mdb.clickhouse.v1.ListExtensionsRequest\x1a\x36.yandex.cloud.mdb.clickhouse.v1.ListExtensionsResponse\")\x82\xd3\xe4\x93\x02#\x12!/managed-clickhouse/v1/extensionsBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.extension_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['extension_name']._loaded_options = None
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['extension_name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_EXTENSIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/managed-clickhouse/v1/extensions/{extension_name}'
  _globals['_EXTENSIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/managed-clickhouse/v1/extensions'
  _globals['_GETEXTENSIONREQUEST']._serialized_start=199
  _globals['_GETEXTENSIONREQUEST']._serialized_end=287
  _globals['_LISTEXTENSIONSREQUEST']._serialized_start=289
  _globals['_LISTEXTENSIONSREQUEST']._serialized_end=403
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_start=405
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_end=517
  _globals['_EXTENSIONSERVICE']._serialized_start=520
  _globals['_EXTENSIONSERVICE']._serialized_end=865
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/link.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/link.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/monitoring/v3/link.proto\x12\x1ayandex.cloud.monitoring.v3\"\x81\x03\n\x04Link\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0fopen_in_new_tab\x18\x02 \x01(\x08\x12\r\n\x03url\x18\x03 \x01(\tH\x00\x12?\n\tdashboard\x18\x04 \x01(\x0b\x32*.yandex.cloud.monitoring.v3.Link.DashboardH\x00\x1a\xf8\x01\n\tDashboard\x12\x14\n\nproject_id\x18\x01 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x16\n\x0e\x64\x61shboard_name\x18\x03 \x01(\t\x12\x18\n\x10\x61pply_time_range\x18\x04 \x01(\x08\x12N\n\nparameters\x18\x05 \x03(\x0b\x32:.yandex.cloud.monitoring.v3.Link.Dashboard.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\tcontainerB\x06\n\x04typeBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.link_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_LINK_DASHBOARD_PARAMETERSENTRY']._loaded_options = None
  _globals['_LINK_DASHBOARD_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_LINK']._serialized_start=70
  _globals['_LINK']._serialized_end=455
  _globals['_LINK_DASHBOARD']._serialized_start=199
  _globals['_LINK_DASHBOARD']._serialized_end=447
  _globals['_LINK_DASHBOARD_PARAMETERSENTRY']._serialized_start=385
  _globals['_LINK_DASHBOARD_PARAMETERSENTRY']._serialized_end=434
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.vrf_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetVrfRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF to return.

    To get the VRF ID, use a [VrfService.List] request.
    """
    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vrf_id", b"vrf_id"]) -> None: ...

global___GetVrfRequest = GetVrfRequest

@typing.final
class ListVrfRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list VRFs in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListConfigurationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListConfigurationsResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "name", "createdAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVrfRequest = ListVrfRequest

@typing.final
class ListVrfResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRFS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListVrfRequest.page_size], use `next_page_token` as the value
    for the [ListVrfRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def vrfs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.vrf_pb2.Vrf]:
        """List of VRF resources."""

    def __init__(
        self,
        *,
        vrfs: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.vrf_pb2.Vrf] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "vrfs", b"vrfs"]) -> None: ...

global___ListVrfResponse = ListVrfResponse

@typing.final
class CreateVrfRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a VRF in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the VRF.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the VRF."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateVrfRequest = CreateVrfRequest

@typing.final
class CreateVrfMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF that is being created."""
    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vrf_id", b"vrf_id"]) -> None: ...

global___CreateVrfMetadata = CreateVrfMetadata

@typing.final
class UpdateVrfRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    VRF_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF to update.

    To get the VRF ID, use a [VrfService.List] request.
    """
    name: builtins.str
    """Name of the VRF.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the VRF."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the VRF should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask", "vrf_id", b"vrf_id"]) -> None: ...

global___UpdateVrfRequest = UpdateVrfRequest

@typing.final
class UpdateVrfMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF that is being updated."""
    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vrf_id", b"vrf_id"]) -> None: ...

global___UpdateVrfMetadata = UpdateVrfMetadata

@typing.final
class DeleteVrfRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF to delete.

    To get the VRF ID, use a [VrfService.List] request.
    """
    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vrf_id", b"vrf_id"]) -> None: ...

global___DeleteVrfRequest = DeleteVrfRequest

@typing.final
class DeleteVrfMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF resource that is being deleted."""
    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vrf_id", b"vrf_id"]) -> None: ...

global___DeleteVrfMetadata = DeleteVrfMetadata

@typing.final
class ListVrfOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListVrfOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListVrfOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "vrf_id", b"vrf_id"]) -> None: ...

global___ListVrfOperationsRequest = ListVrfOperationsRequest

@typing.final
class ListVrfOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListVrfOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListVrfOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified VRF resource."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListVrfOperationsResponse = ListVrfOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/logging.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/logging.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.rpc import code_pb2 as google_dot_rpc_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/apploadbalancer/v1/logging.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x15google/rpc/code.proto\"\xe8\x01\n\x0eLogDiscardRule\x12\x1f\n\nhttp_codes\x18\x01 \x03(\x03\x42\x0b\xfa\xc7\x31\x07\x31\x30\x30-599\x12N\n\x13http_code_intervals\x18\x02 \x03(\x0e\x32\x31.yandex.cloud.apploadbalancer.v1.HttpCodeInterval\x12$\n\ngrpc_codes\x18\x03 \x03(\x0e\x32\x10.google.rpc.Code\x12?\n\x0f\x64iscard_percent\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\"{\n\nLogOptions\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\x46\n\rdiscard_rules\x18\x02 \x03(\x0b\x32/.yandex.cloud.apploadbalancer.v1.LogDiscardRule\x12\x0f\n\x07\x64isable\x18\x03 \x01(\x08*\x8a\x01\n\x10HttpCodeInterval\x12\"\n\x1eHTTP_CODE_INTERVAL_UNSPECIFIED\x10\x00\x12\x0c\n\x08HTTP_1XX\x10\x01\x12\x0c\n\x08HTTP_2XX\x10\x02\x12\x0c\n\x08HTTP_3XX\x10\x03\x12\x0c\n\x08HTTP_4XX\x10\x04\x12\x0c\n\x08HTTP_5XX\x10\x05\x12\x0c\n\x08HTTP_ALL\x10\x06\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.logging_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _globals['_LOGDISCARDRULE'].fields_by_name['http_codes']._loaded_options = None
  _globals['_LOGDISCARDRULE'].fields_by_name['http_codes']._serialized_options = b'\372\3071\007100-599'
  _globals['_LOGDISCARDRULE'].fields_by_name['discard_percent']._loaded_options = None
  _globals['_LOGDISCARDRULE'].fields_by_name['discard_percent']._serialized_options = b'\372\3071\0050-100'
  _globals['_HTTPCODEINTERVAL']._serialized_start=529
  _globals['_HTTPCODEINTERVAL']._serialized_end=667
  _globals['_LOGDISCARDRULE']._serialized_start=169
  _globals['_LOGDISCARDRULE']._serialized_end=401
  _globals['_LOGOPTIONS']._serialized_start=403
  _globals['_LOGOPTIONS']._serialized_end=526
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/v1/customer.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/v1/customer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/billing/v1/customer.proto\x12\x17yandex.cloud.billing.v1\"2\n\x08\x43ustomer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\"\x9b\x01\n\x0e\x43ustomerPerson\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08longname\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x11\n\tpost_code\x18\x05 \x01(\t\x12\x14\n\x0cpost_address\x18\x06 \x01(\t\x12\x15\n\rlegal_address\x18\x07 \x01(\t\x12\x0b\n\x03tin\x18\x08 \x01(\tBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.customer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _globals['_CUSTOMER']._serialized_start=67
  _globals['_CUSTOMER']._serialized_end=117
  _globals['_CUSTOMERPERSON']._serialized_start=120
  _globals['_CUSTOMERPERSON']._serialized_end=275
# @@protoc_insertion_point(module_scope)
